summaryrefslogtreecommitdiffstats
path: root/src/include/usr/mbox
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/usr/mbox')
-rw-r--r--src/include/usr/mbox/mboxif.H12
1 files changed, 10 insertions, 2 deletions
diff --git a/src/include/usr/mbox/mboxif.H b/src/include/usr/mbox/mboxif.H
index 1f56d6c95..497a22893 100644
--- a/src/include/usr/mbox/mboxif.H
+++ b/src/include/usr/mbox/mboxif.H
@@ -116,13 +116,21 @@ namespace MBOX
/**
* Suspend the mailbox.
*
+ * @param[in] i_disable_hw_int, disable interrupts from hw along
+ * with SW suspend. Defaults to SW suspend only
+ * @param[in] i_allow_resp, Allow suspend to happen even if
+ * there are pending HB responses to FSP. Use
+ * with extreme caution
+ *
* @return error handle on error
*
* @note:
* Any message sent to the FSP will be queued and send after the mailbox
* is resumed. Interrupts from the FSP MBox will be masked.
*/
- errlHndl_t suspend();
+ errlHndl_t suspend(bool i_disable_hw_int = false,
+ bool i_allow_resp = false);
/**
* Resume the mailbox
OpenPOWER on IntegriCloud
@@ -116,13 +116,21 @@ namespace MBOX
* @note:
* Any message sent to the FSP will be queued and send after the mailbox
- * is resumed. Interrupts from the FSP MBox will be masked.
+ * is resumed. Interrupts from the FSP MBox will be masked if
+ * i_disable_hw_int is set
*/